# Welcome to tsinfer's documentation!

This is the documentation for {program}`tsinfer`, a method for inferring correlated
genealogies (a.k.a. tree sequence or ARGs) from genetic variation data.

Besides this manual, there are a number of other resources
available for learning about {program}`tskit` and {program}`tsinfer`:

- The [tskit tutorials](https://tskit.dev/tutorials) site contains
  in-depth tutorials on analysis of the {program}`tskit` tree sequences produced by
  {program}`tsinfer`.

- Our [Discussions board](https://github.com/tskit-dev/tsinfer/discussions)
  is a great place to ask questions like "how do I do X" or "what's the best
  way to do Y". Please make questions as clear as possible, and be respectful,
  helpful, and kind.

```{important}
If you use {program}`tsinfer` in your work, please remember to
cite it appropriately: see the {ref}`citations<sec_citation>` page
for details.
```


## Contents

```{tableofcontents}
```
